api.system.components.code.v1.test_helpers.profile package — Argus-Toolbelt 1.0 documentation

# api.system.components.code.v1.test_helpers.profile package

## Submodules

## api.system.components.code.v1.test_helpers.profile.attach module

`api.system.components.code.v1.test_helpers.profile.attach.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.attach.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.attach.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.attach.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.attach_by_name module

`api.system.components.code.v1.test_helpers.profile.attach_by_name.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.attach_by_name.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.attach_by_name.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.attach_by_name.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.attach_detach module

`api.system.components.code.v1.test_helpers.profile.attach_detach.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.attach_detach.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.attach_detach.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.attach_detach.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.create module

`api.system.components.code.v1.test_helpers.profile.create.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.create.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.create.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.create.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.delete module

`api.system.components.code.v1.test_helpers.profile.delete.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.delete.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.delete.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.delete.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.detach module

`api.system.components.code.v1.test_helpers.profile.detach.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.detach.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.detach.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.detach.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.detach_by_artifact_by_g_a module

`api.system.components.code.v1.test_helpers.profile.detach_by_artifact_by_g_a.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.detach_by_artifact_by_g_a.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.detach_by_artifact_by_g_a.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.detach_by_artifact_by_g_a.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.detach_by_name module

`api.system.components.code.v1.test_helpers.profile.detach_by_name.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.detach_by_name.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.detach_by_name.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.detach_by_name.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/artifacts/w+/w+/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.duplicate module

`api.system.components.code.v1.test_helpers.profile.duplicate.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/duplicate/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.duplicate.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/duplicate/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.duplicate.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/duplicate/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.duplicate.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+/duplicate/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.get_by_id module

`api.system.components.code.v1.test_helpers.profile.get_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.get_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.get_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.get_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.get_by_name module

`api.system.components.code.v1.test_helpers.profile.get_by_name.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.get_by_name.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.get_by_name.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.get_by_name.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.list module

`api.system.components.code.v1.test_helpers.profile.list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.search module

`api.system.components.code.v1.test_helpers.profile.search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/search, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/search, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/search, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/search, respond with HTTP 401

## api.system.components.code.v1.test_helpers.profile.update module

`api.system.components.code.v1.test_helpers.profile.update.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.profile.update.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.profile.update.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.profile.update.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/profile/w+, respond with HTTP 401

## Module contents